PointerErrorKind

Enum PointerErrorKind 

pub enum PointerErrorKind {
Show 13 variants InvalidSyntax, InvalidEscape, EmptyDocument, MissingValue, TypeMismatch, InvalidIndex, IndexOutOfBounds, DashNotAllowed, NonStringKey, AmbiguousKey, UnresolvedAlias, AliasCycle, Semantic,
}
Classification of a JSON Pointer parse or resolution failure.

Variants



InvalidSyntax

The whole pointer has invalid syntax.



InvalidEscape

A reference token contains an invalid ~ escape.



EmptyDocument

The selected YAML document has no root node.



MissingValue

A mapping member or sequence item does not exist.



TypeMismatch

A reference token was evaluated against a scalar.



InvalidIndex

A sequence token is not a canonical unsigned index.



IndexOutOfBounds

A canonical sequence index is larger than the sequence.



DashNotAllowed

The special - token was used outside an add destination.



NonStringKey

A traversed YAML mapping contains a non-string key.



AmbiguousKey

More than one mapping key matches the token.



UnresolvedAlias

An alias has no preceding anchor binding.



AliasCycle

An alias chain is cyclic.



Semantic

A YAML semantic operation failed during resolution.