pub enum YamlPatchErrorKind {
Syntax,
Structure,
Application,
}Expand description
Classification of a YAML patch failure.
Variants
Syntax
The patch source is not valid YAML.
Structure
The parsed document is not a valid patch document.
Application
A valid operation could not be applied to the target document.