pub struct Diagnostic {
pub kind: DiagnosticKind,
pub message: String,
pub span: Span,
pub position: Option<LineCol>,
pub expected: Vec<String>,
pub notes: Vec<String>,
}Expand description
Structured user-facing diagnostic.
Fields
kind: DiagnosticKindError phase.
message: StringPrimary message.
span: SpanPrimary source span.
position: Option<LineCol>One-based line/column for the primary span when a source is available.
expected: Vec<String>Expected syntax or semantic items.
notes: Vec<String>Additional context notes.
Implementations
Sourceimpl Diagnostic
impl Diagnostic
Sourcepub fn new(
kind: DiagnosticKind,
message: impl Into<String>,
span: Span,
) -> Diagnostic
pub fn new( kind: DiagnosticKind, message: impl Into<String>, span: Span, ) -> Diagnostic
Creates a diagnostic with no expected items or notes.
Sourcepub const fn with_position(self, position: LineCol) -> Diagnostic
pub const fn with_position(self, position: LineCol) -> Diagnostic
Sets a one-based line/column position for the primary span.
Sourcepub fn with_expected(self, expected: impl Into<String>) -> Diagnostic
pub fn with_expected(self, expected: impl Into<String>) -> Diagnostic
Adds one expected syntax or semantic item.
Sourcepub fn with_note(self, note: impl Into<String>) -> Diagnostic
pub fn with_note(self, note: impl Into<String>) -> Diagnostic
Adds one explanatory note.