Number

Struct Number 

pub struct Number { /* private fields */ }
A YAML integer or floating-point number.

Unlike yaml_serde::Number, this type retains the full Serde i128 and u128 ranges.

Implementations

Source

impl Number

pub fn is_i64(&self) -> bool

Returns true when this is an integer representable as i64.

pub fn is_u64(&self) -> bool

Returns true when this is an integer representable as u64.

pub const fn is_f64(&self) -> bool

Returns true when this was represented as a floating-point number.

pub fn is_i128(&self) -> bool

Returns true when this is an integer representable as i128.

pub fn is_u128(&self) -> bool

Returns true when this is an integer representable as u128.

pub fn as_i64(&self) -> Option<i64>

Returns the integer as i64 when it fits.

pub fn as_u64(&self) -> Option<u64>

Returns the integer as u64 when it fits.

pub fn as_i128(&self) -> Option<i128>

Returns the integer as i128 when it fits.

pub fn as_u128(&self) -> Option<u128>

Returns the integer as u128 when it is non-negative.

pub fn as_f64(&self) -> Option<f64>

Returns this number as f64.

pub fn is_nan(&self) -> bool

Returns true when this is NaN.

pub fn is_infinite(&self) -> bool

Returns true when this is positive or negative infinity.

pub fn is_finite(&self) -> bool

Returns true when this is not infinity or NaN.