YamlFragment

Struct YamlFragment 

pub struct YamlFragment { /* private fields */ }
A parsed YAML value document containing exactly one root node.

Implementations

Source

impl YamlFragment

pub fn parse_owned(input: String) -> Result<YamlFragment, FragmentError>

Parses an owned YAML value.

Errors

Returns an error when the input is invalid YAML, does not contain exactly one rooted document, or contains an alias that escapes the value root.

pub fn parse(input: &str) -> Result<YamlFragment, FragmentError>

Parses a borrowed YAML value.

Errors

Returns an error under the same conditions as Self::parse_owned.

pub fn document(&self) -> &YamlDoc

Returns the fragment’s parsed document.

pub const fn root(&self) -> NodeId

Returns the fragment root node.

pub fn to_yaml(&self) -> Result<String, FragmentError>

Returns the root as minimally de-indented standalone YAML.

Errors

Returns an error when the stored root node is no longer valid.