pub struct YamlFragment { /* private fields */ }Expand description
A parsed YAML value document containing exactly one root node.
Implementations
Sourceimpl YamlFragment
impl YamlFragment
Sourcepub fn parse_owned(input: String) -> Result<YamlFragment, FragmentError>
pub fn parse_owned(input: String) -> Result<YamlFragment, FragmentError>
Parses an owned YAML value.
Errors
Returns an error when the input is invalid YAML, does not contain exactly one rooted document, or contains an alias that escapes the value root.
Sourcepub fn parse(input: &str) -> Result<YamlFragment, FragmentError>
pub fn parse(input: &str) -> Result<YamlFragment, FragmentError>
Parses a borrowed YAML value.
Errors
Returns an error under the same conditions as Self::parse_owned.